StreetFilms Video Gallery - The New York City Streets Renaissance
Author: New York City Streets Renaissance

# The New York City Streets Renaissance

- Home Page
- Join Us

## StreetFilms Video Gallery

### Recently Added Videos

- Above The Law: Govt. Parking Permit Abuse in NYC Transportation Alternatives releases a comprehensive study on permit parking abuse. (3:54 - 15.81 MB)
- Car-free Central Park Rally A rally on the steps of City Hall demonstrates residents' support for a car-free Central Park. (4:24 - 17.59 MB)
- Nicole's Journey Bronx resident, Nicole Duncan, exposes the dangerous pedestrian conditions while walking her children to school. (14:27 - 59.78 MB)
- The Top Ten Reasons I Shouldn't Get a Ticket This short video highlights the number of excuses drivers in New York City make everyday in effort to avoid a ticket while parking illegally. (1:08 - 4.16 MB)
- Portland, OR - Crosswalk Enforcement Actions In Portland, OR, you can get a $242 ticket for failing to yield to a pedestrian in a crosswalk. (1:36 - 5.77 MB)
- Atlantic Avenue Residents, business-people and community leaders speak out against the speeding and congestions problems on Brooklyn's Atlantic Avenue that have resulted in a number of recent accident-related fatalities. (3:46 - 14.73 MB)

### Previous Videos

- Introduction Mark Gorton introduces the goals of the NYC Streets Renaissance project. (1:00 - 2.71 MB)
- Portland, OR - Innovative Bicycle Signal This unique bike signal gives Portland cyclists the right of way! (1:37 - 5.91 MB)
- Portland, OR - Safe Routes to School This Portland institution emphasizes using non-motorized means to get to school. (4:14 - 16.40 MB)
- Portland, OR - Older Adults Bike Program Seniors in Portland ride three-wheeled trikes thanks to a program by the Portland Office of Transportation (PDOT). (3:31 - 17.37 MB)
- Portland, OR - Festival Streets Innovative thinking in Portland has produced a new street design which emphasizes community use. (3:39 - 13.93 MB)
- Portland, OR - Traffic Calming: Diagonal Diverter The use of traffic calming in Portland emphasizes keeping thru traffic out of neighborhoods. (1:20 - 5.57 MB)
- Portland, OR - Bicycle Boulevards Who needs bike lanes on wonderful streets like these when you keep traffic to a minimum? (3:08 - 12.12 MB)
- Hell's Kitchen: Neighborhood Under Siege Residents protest the DOT's transformation of 9th Avenue, adding more space for cars and destroying the neighborhood in the process. (14:37 - 41.49 MB)
- Interview with Enrique Peñalosa (Long) Former Bogotá mayor Enrique Peñalosa discusses his amazing success transforming Bogotá into a livable city for cyclists and pedestrians. (12:07 - 51.26 MB)
- Lessons from San Francisco After an earthquake, the Embarcadero Freeway was replaced with a grand boulevard which has rejuvenated its waterfront. (12:04 - 52.45 MB)
- Lessons From Portland The Mt. Hood Freeway's defeat in the 1970s positively impacted Portland, Oregon's future, creating a more livable city. (11:42 - 50.01 MB)
- A conversation with Lou Riccio Discussion about the transportation planning with former NYC D.O.T. Commissioner Lou Riccio. (10:57 - 44.69 MB)
- Grand Army Plaza Traffic Survey Residents and neighborhood leaders of GAPCO evaluate how traffic conditions could be improved for pedestrians. (9:00 - 41.03 MB)
- Jan Gehl in Times Square Jan Gehl (Gehl Architects) and Mark Gorton discuss the potential for pedestrian-friendly changes in Times Square. (8:31 - 28.08 MB)
- Lessons From Canal Park Richard Barrett talks about his community's struggle to rebuild Canal Park, a task deemed impossible by New York City's Department of Transportation. (8:00 - 36.77 MB)
- Park(ing) Day San Francisco In San Francisco, organizations temporarily liberated over two dozen parking spots, turning them into temporary green spaces for pedestrians. (6:51 - 38.24 MB)
- Greenwich Street This heavily-used crosswalk on Greenwich Street is constantly ignored by drivers. (6:07 - 33.49 MB)
- Fulton Street Jeff Prant collects signatures on his petition to maintain Fulton Street's car-free hours. (5:48 - 31.04 MB)
- The Sidewalk Nibblers A proposed plan by DOT for a subway station at 96th street will leave pedestrians with 18 ft. less sidewalk space! (5:38 - 26.42 MB)
- "Gridlock Sam": Central Park Sam Schwartz, former NYC Commissioner of Traffic, explains how closing Central Park to cars will not result in traffic chaos. (5:23 - 13.18 MB)
- "Gridlock Sam": Parking Permits In the second part of our interview with "Gridlock Sam" Schwartz, the topic is Government Parking Permits. (5:06 - 13.80 MB)
- What About The Children? Holy Cross School Principal, Sister Mary Teresa Dixon, talks about her many attempts to get the NYC DOT to help with traffic conditions outside of her school. (4:56 - 21.92 MB)
- Parking Spot Squat Volunteers take over a parking spot for a day to reclaim it for public use in Park Slope, Brooklyn. (4:46 - 23.15 MB)
- Car-free Sunday on the Grand Concourse Residents of the Bronx take to the streets when part of the Grand Concourse is closed to cars. (3:58 - 21.59 MB)
- Interview with Enrique Peñalosa (Short) Former Bogotá mayor Enrique Peñalosa discusses his amazing success transforming Bogotá into a livable city for cyclists and pedestrians. (3:08 - 12.75 MB)
- Public Space Transformations These photo simulations from the Project for Public Spaces show how we can transform some of our misused intersections. (2:00 - 3.79 MB)
- Broadway & Houston One of the busiest pedestrian crossings in the city is to become even more car-friendly at the expense of pedestrian safety. (1:51 - 7.20 MB)
- Psychic Space Mark Gorton points out how parking and street design on two SoHo streets can make a huge impact on pedestrians. (1:37 - 8.97 MB)
- Miracle Ticket Sometimes when you are armed with a camera in New York City, miracles can happen. (1:13 - 6.80 MB)
- When do we go? A few minutes of condensed footage of pedestrians intrepidly navigating traffic at Broome and Broadway. (1:11 - 3.85 MB)
- Dirty Little Secret An inequitable use of parking by government agencies is a dirty little secret in Chinatown. (0:56 - 5.07 MB)
- Grand Street Redesigned Mark Gorton tours Grand Street in Chinatown, pointing out the nonsensical difference in space allotted to cars and pedestrians. (0:50 - 2.27 MB)
- Pedestrian Obstacle Course A visual example of the hoops through which a pedestrian must jump to cross a street in Times Square. (0:46 - 4.88 MB)
- So Why Are They Driving? Nearly every person who drives into New York City has an alternate means of transportation. (0:30 - 3.38 MB)
- Pedestrian Density Cars get more space than pedestrians do on the streets, which leads to overcrowded sidewalks. (0:30 - 2.42 MB)
- We're Walking While walking around Manhattan, pedestrians might wonder where all the cars come from. After seeing these statistics, it seems obvious. (0:30 - 1.73 MB)
- Cab in a Crosswalk See how much disruption and danger one taxi cab stuck in a Times Square crosswalk can create. (0:28 - 3.25 MB)